﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using System.Collections.ObjectModel;

namespace SeriesUpdating
{
    public class ViewModel : INotifyPropertyChanged
    {
        private ObservableCollection<ChartData> cdc1;
        private ObservableCollection<ChartData> cdc2;

        public ObservableCollection<ChartData> Series1
        {
            get { return cdc1; }
            set
            {
                if (cdc1 != value)
                {
                    cdc1 = value;
                    OnPropertyChanged("Series1");
                }
            }
        }

        public ObservableCollection<ChartData> Series2
        {
            get { return cdc2; }
            set
            {
                if (cdc2 != value)
                {
                    cdc2 = value;
                    OnPropertyChanged("Series2");
                }
            }
        }

        public ViewModel()
        {
            CreateInitialSeries();
        }

        private void CreateInitialSeries()
        {
            Series1 = new ObservableCollection<ChartData>();
            Series2 = new ObservableCollection<ChartData>();

            Random random = new Random();


            for (int i = 0; i < 20; i++)
            {
                ChartData cd = new ChartData()
                {
                    XValue = i,
                    YValue = i+2,
                    Description = "Pt 1-" + i.ToString()
                };
                Series1.Add(cd);
                cd = new ChartData()
                {
                    XValue = i+5,
                    YValue = i+5,
                    Description = "Pt 2-" + i.ToString()
                };
                Series2.Add(cd);
            }

        }

        public void UpdateSeries1()
        {
            int cnt = Series1.Count;

            for (int i = cnt; i < (cnt + 10); i++)
            {
                ChartData cd = new ChartData()
                {
                    XValue = i,
                    YValue = i + cnt,
                    Description = "Pt 1-" + i.ToString()
                };
                Series1.Add(cd);
            }
        }
        public void UpdateSeries2()
        {
            int cnt = Series2.Count;

            for (int i = cnt; i < (cnt + 10); i++)
            {
                ChartData cd = new ChartData()
                {
                    XValue = i+1,
                    YValue = i + cnt + 10,
                    Description = "Pt 2-" + i.ToString()
                };
                Series2.Add(cd);
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;
        protected virtual void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

    }

    public class ChartData : INotifyPropertyChanged
    {
        private double xVal;
        private double yVal;
        private string desc;



        public double XValue
        {
            get { return xVal; }
            set
            {
                if (xVal != value)
                {
                    xVal = value;
                    OnPropertyChanged("XValue");
                }
            }
        }

        public double YValue
        {
            get { return yVal; }
            set
            {
                if (yVal != value)
                {
                    yVal = value;
                    OnPropertyChanged("YValue");
                }
            }
        }

        public string Description
        {
            get { return desc; }
            set
            {
                if (desc != value)
                {
                    desc = value;
                    OnPropertyChanged("Description");
                }
            }
        }



        public event PropertyChangedEventHandler PropertyChanged;
        protected virtual void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}
